summaryrefslogtreecommitdiffstats
path: root/editor/animation_track_editor.h
diff options
context:
space:
mode:
authoremild <emil.dobetsberger@gmail.com>2024-02-12 14:28:13 +0100
committerRémi Verschelde <rverschelde@gmail.com>2024-02-13 10:32:50 +0100
commitb66b188cf9a310940283a544aaf0b3c37b923e96 (patch)
tree945f7e002137affaa2fb6a97489ea30e862e9514 /editor/animation_track_editor.h
parent9272f7b53db1f7f142df43981adec5cebdfbd179 (diff)
downloadredot-engine-b66b188cf9a310940283a544aaf0b3c37b923e96.tar.gz
Fix vertical zoom factor in Animation Bezier Editor
Diffstat (limited to 'editor/animation_track_editor.h')
-rw-r--r--editor/animation_track_editor.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/editor/animation_track_editor.h b/editor/animation_track_editor.h
index 6d037bf5f9..bb84577ba3 100644
--- a/editor/animation_track_editor.h
+++ b/editor/animation_track_editor.h
@@ -134,7 +134,8 @@ class AnimationTimelineEdit : public Range {
friend class AnimationBezierTrackEdit;
friend class AnimationTrackEditor;
- static constexpr float SCROLL_ZOOM_FACTOR = 1.02f; // Zoom factor per mouse scroll in the animation editor. The closer to 1.0, the finer the control.
+ static constexpr float SCROLL_ZOOM_FACTOR_IN = 1.02f; // Zoom factor per mouse scroll in the animation editor when zooming in. The closer to 1.0, the finer the control.
+ static constexpr float SCROLL_ZOOM_FACTOR_OUT = 0.98f; // Zoom factor when zooming out. Similar to SCROLL_ZOOM_FACTOR_IN but less than 1.0.
Ref<Animation> animation;
bool read_only = false;